<?php
/**
 * @file
 * Provides administration functions for the slim_time module.
 *
 * @ingroup slim_time
 * @{
 */

/**
 * Helper function for the slim time widget settings.
 *
 * @see slim_time_field_widget_settings_form().
 */
function _slim_time_field_widget_settings_form($field, $instance) {
  $widget = $instance['widget'];
  $settings = $widget['settings'] + field_info_widget_settings($widget['type']);
  $form = array();
  switch ($widget['type']) {
    case 'slim_time_textfield':

      $form['size'] = array(
        '#type' => 'textfield',
        '#title' => t('Form width'),
        '#description' => t('Width the of the form input element.'),
        '#default_value' => $settings['size'],
        '#required' => TRUE,
        '#size' => 10,
      );

      $form['slim_time'] = array(
        '#type' => 'fieldset',
        '#title' => t('Slim Time options'),
        '#collapsible' => FALSE,
      );
      $form['slim_time']['fuzzy'] = array(
        '#type' => 'checkbox',
        '#title' => t('Fuzzy'),
        '#default_value' => $settings['fuzzy'],
        '#description' => t('Recognize time from within a phrase.'),
      );
      $form['slim_time']['default'] = array(
        '#type' => 'radios',
        '#title' => t('Format'),
        '#default_value' => $settings['default'],
        '#options' => array(
          12 => t('12 hour'),
          24 => t('24 hour'),
        ),
      );
      $form['slim_time']['assume'] = array(
        '#type' => 'radios',
        '#title' => t('Assume'),
        '#description' => t('What to assume when missing a suffix.'),
        '#default_value' => $settings['assume'],
        '#options' => array(
          'am' => t('am'),
          'pm' => t('pm'),
        ),
      );
      $form['slim_time']['colon'] = array(
        '#type' => 'select',
        '#title' => t('Colon handling'),
        '#description' => t('To allow en entry like "615" for 6:15am set this to <em>optional</em>.  To not use a colon, set this to <em>none</em>.'),
        '#default_value' => $settings['colon'],
        '#options' => array(
          'none' => t('None'),
          'optional' => t('Optional'),
          'required' => t('Required'),
        ),
      );
      break;
  }

  return $form;  
}
